==> wfde-3.01.08.tar.gz: wfde-3.01.08/warftpd/WarftpdLite.h <==
/** 
*/

#ifndef WAR_FTPD_LITE_H
#define WAR_FTPD_LITE_H


/* These values can be changed for derived programs */
#ifndef VERSION
#   define VERSION WAR_VERSION"-0-pre-beta"
#endif

#ifndef PROGRAM
#   define PROGRAM "War FTP Daemon Lite"
#endif

#ifndef COPYRIGHT
#   define COPYRIGHT "Copyright 1996 - 2001 Jarle (jgaa) Aase, http://www.jgaa.com"
#endif

#ifndef LICENSE
#   define LICENSE \
"This is free software; you can redistribute it and/or\n" \
"modify it under the terms of the GNU Lesser General Public\n" \
"License as published by the Free Software Foundation; either\n" \
"version 2.1 of the License, or (at your option) any later version.\n"
#endif

#ifndef DEFAULT_FTP_SVR_NAME
#   define DEFAULT_FTP_SVR_NAME "Jgaa's fan club FTP server"
#endif

#ifndef NT_EVENT_TAG
#   define NT_EVENT_TAG "WarFTPD Lite"
#endif

#ifndef DEFAULT_USER_NAME
#   ifdef WIN32
#       define DEFAULT_USER_NAME "System";
#   else
#       define DEFAULT_USER_NAME "root";
#   endif
#endif


/* SYSTEM INCLUDES */

#ifndef WAR_INCLUDED_TCHAR_H
#   define WAR_INCLUDED_TCHAR_H
#   include <tchar.h>
#endif

/* PROJECT INCLUDES */

#include "WarThread.h"
#include "WarLog.h"
#include "WarLogIOStreamHandler.h"
#include "WarSvrEngine.h"
#include "WarSvrDefinitionFtp.h"
#include "WarSvrProtocolFtp.h"
#include "WarSocketEngine.h"
#include "WarSvrWin32NtEngine.h"
#include "WarFileEngine.h"
#include "WarFileDriverWin32.h"
#include "WarUserAuthWin32Nt.h"
#include "WarOs.h"
#include "WarUtf8.h"
#include "WarWin32Registry.h" 
#include "WarWin32NtService.h"
#include "WarTimer.h"
#include "WarShutdownEngine.h"
#include "WarPerfmonDef.h"

#include "war_ftpdlite_custom.h"

/* LOCAL INCLUDES */


/* FORWARD REFERENCES */
int main(int argc, char* argv[]);
void ParseOptions(int argc, char* argv[]);
void Usage(char *bad_arg, char *explain);
void ShowHelp(void);
void DoAutostart();
void DoInstall();
int StartServer();

#ifdef WIN32
    void InitWin32();
    void InitWin32Nt();
    void WarInstallServerOptionsWin32(const WarWin32Registry& key);
    void WarInstallFtpServerOptionsWin32(const WarWin32Registry& key);
#endif // WIN32

// Global variables
const typedef struct PriorityMapTable
{
    WarPrioritiesDefE priority;
    war_ccstr_t name;
} priority_map_t;

class WarPreMainInit
{
public:
    WarPreMainInit()
    {
        // Initialize core modules in the library
        // before we create objects that depend on
        // them
        ::CoInitialize(NULL);
        WarSmartPointer::Initialize();
    }

    ~WarPreMainInit()
    {
        ::CoUninitialize();
    }
};

#ifndef EXT
#   define EXT extern
#endif
EXT char *myname;
EXT int DaemonFlag, InstallFlag, AutostartFlag, 
    ConfigFlag, DebugFlag, VerboseFlag, ProfilerFlag;
EXT std::string ServiceName, UserName,  
    RootPath, DebugLogOptions;
extern WarCollector<char> UserPasswd;
EXT WarOs WarOsObject;
EXT WarPreMainInit PreMainInit;
EXT WarShutdownEngine ShutdownEngineObject;
EXT WarPrioritiesDefE Priority;
EXT WarLogEngine LogEngine;
EXT std::ofstream LogFile;
EXT WarFileEngine FileEngineObject;
EXT WarSocketEngine SocketEngineObject;
EXT WarSvrEngine ServerEngineObject;
#ifdef WIN32
    EXT WarSvrWin32NtEngine win32nt_engine;
#endif
extern const priority_map_t PriorityMapTable[WAR_THRD_PRI_INVALID +1];


#ifdef __cplusplus
extern "C" 
{
#endif
/****************** BEGIN OLD STYLE C spesific ********/

/****************** END OLD STYLE C spesific **********/
#ifdef __cplusplus 
}
#endif

/****************** BEGIN C++ spesific ****************/

#ifdef __cplusplus

/* INLINE METHODS */

/* EXTERNAL REFERENCES */

#endif /* __cplusplus */

/****************** END C++ spesific ******************/

#endif  /* WAR_FTPD_LITE_H_ */

==> wfde-3.01.10.tar.gz: wfde-3.01.10/warftpd/WarftpdLite.h <==
/** 
*/

#ifndef WAR_FTPD_LITE_H
#define WAR_FTPD_LITE_H


/* These values can be changed for derived programs */
#ifndef VERSION
#   define VERSION WAR_VERSION"-0-pre-beta"
#endif

#ifndef PROGRAM
#   define PROGRAM "War FTP Daemon Lite"
#endif

#ifndef COPYRIGHT
#   define COPYRIGHT "Copyright 1996 - 2001 Jarle (jgaa) Aase, http://www.jgaa.com"
#endif

#ifndef LICENSE
#   define LICENSE \
"This is free software; you can redistribute it and/or\n" \
"modify it under the terms of the GNU Lesser General Public\n" \
"License as published by the Free Software Foundation; either\n" \
"version 2.1 of the License, or (at your option) any later version.\n"
#endif

#ifndef DEFAULT_FTP_SVR_NAME
#   define DEFAULT_FTP_SVR_NAME "Jgaa's fan club FTP server"
#endif

#ifndef NT_EVENT_TAG
#   define NT_EVENT_TAG "WarFTPD Lite"
#endif

#ifndef DEFAULT_USER_NAME
#   ifdef WIN32
#       define DEFAULT_USER_NAME "FTP-Server";
#   else
#       define DEFAULT_USER_NAME "root";
#   endif
#endif


/* SYSTEM INCLUDES */

#ifndef WAR_INCLUDED_TCHAR_H
#   define WAR_INCLUDED_TCHAR_H
#   include <tchar.h>
#endif

/* PROJECT INCLUDES */

#include "WarThread.h"
#include "WarLog.h"
//#include "WarLogIOStreamHandler.h"
//#include "WarSvrEngine.h"
//#include "WarSvrDefinitionFtp.h"
//#include "WarSvrProtocolFtp.h"
//#include "WarSocketEngine.h"
//#include "WarSvrWin32NtEngine.h"
//#include "WarFileEngine.h"
//#include "WarFileDriverWin32.h"
//#include "WarUserAuthWin32Nt.h"
//#include "WarOs.h"
//#include "WarUtf8.h"
#include "WarWin32Registry.h" 
//#include "WarWin32NtService.h"
//#include "WarTimer.h"
//#include "WarShutdownEngine.h"
//#include "WarPerfmonDef.h"
//#include "WarSessionManager.h"
//#include "WarPluginEngine.h"
//#include "WarSocketCpsLimit.H"

#include "war_ftpdlite_custom.h"

/* LOCAL INCLUDES */


/* FORWARD REFERENCES */
int main(int argc, char* argv[]);
void ParseOptions(int argc, char* argv[]);
void Usage(char *bad_arg, char *explain);
void ShowHelp(void);
void DoAutostart();
void DoInstall();
int StartServer();

#ifdef WIN32
    void InitWin32();
    void InitWin32Nt();
    void WarInstallServerOptionsWin32(const WarWin32Registry& key);
#endif // WIN32

// Global variables
const typedef struct PriorityMapTable
{
    WarPrioritiesDefE priority;
    war_ccstr_t name;
} priority_map_t;


#ifndef EXT
#   define EXT extern
#endif
EXT char *myname;
EXT int DaemonFlag, InstallFlag, AutostartFlag, 
    ConfigFlag, DebugFlag, VerboseFlag, ProfilerFlag;
EXT std::string ServiceName,  
    RootPath, DebugLogOptions;
EXT WarPrioritiesDefE Priority;
extern WarCollector<TCHAR> UserPasswd, UserName;
extern const priority_map_t PriorityMapTable[WAR_THRD_PRI_INVALID +1];


#ifdef __cplusplus
extern "C" 
{
#endif
/****************** BEGIN OLD STYLE C spesific ********/

/****************** END OLD STYLE C spesific **********/
#ifdef __cplusplus 
}
#endif

/****************** BEGIN C++ spesific ****************/

#ifdef __cplusplus

/* INLINE METHODS */

/* EXTERNAL REFERENCES */

#endif /* __cplusplus */

/****************** END C++ spesific ******************/

#endif  /* WAR_FTPD_LITE_H_ */
